import fs from "fs/promises"
import path from "path"
import { chapters } from "../data/chapters"

// Function to generate consistent slugs
const generateSlug = (text: string) => {
  return text
    .toLowerCase()
    .replace(/\s+/g, "-")
    .replace(/[^\w-]/g, "") // Remove special characters
}

async function generateLessonFiles() {
  console.log("Génération des fichiers de leçons...")

  for (const chapter of chapters) {
    const chapterId = generateSlug(chapter.chapter.split(". ")[1])

    // Créer le dossier du chapitre s'il n'existe pas
    const chapterDir = path.join(process.cwd(), "data", "lessons", chapterId)
    try {
      await fs.mkdir(chapterDir, { recursive: true })
      console.log(`Dossier créé: ${chapterDir}`)
    } catch (error) {
      console.error(`Erreur lors de la création du dossier ${chapterDir}:`, error)
    }

    // Générer un fichier HTML pour chaque leçon
    for (const lesson of chapter.lessons) {
      const lessonId = generateSlug(lesson.title)
      const filePath = path.join(chapterDir, `${lessonId}.html`)

      // Vérifier si le fichier existe déjà
      try {
        await fs.access(filePath)
        console.log(`Le fichier ${filePath} existe déjà, passage à la leçon suivante.`)
        continue
      } catch {
        // Le fichier n'existe pas, on le crée
      }

      // Contenu HTML de base pour la leçon
      const htmlContent = `
<h2>${lesson.title}</h2>

<p>${lesson.description}</p>

<h3>Contenu de la leçon</h3>

<p>Cette leçon fait partie du chapitre "${chapter.chapter}". Le contenu détaillé sera ajouté ultérieurement.</p>

<div class="alert alert-info">
  <p><strong>Note:</strong> Ce fichier a été généré automatiquement. Veuillez remplacer ce contenu par le contenu réel de la leçon.</p>
</div>
      `.trim()

      try {
        await fs.writeFile(filePath, htmlContent)
        console.log(`Fichier créé: ${filePath}`)
      } catch (error) {
        console.error(`Erreur lors de la création du fichier ${filePath}:`, error)
      }
    }
  }

  console.log("Génération des fichiers de leçons terminée.")
}

// Exécuter la fonction
generateLessonFiles()
